@@ -56,34 +56,34 @@ HIVEIT_1_PERCENT = HIVEIT_100_PERCENT / 100
 
 
 class Commit(object):
-    """ Commit things to the Hive network.
+    """Commit things to the Hive network.
 
-        This class contains helper methods to construct, sign and broadcast
-        common transactions, such as posting, voting, sending funds, etc.
+    This class contains helper methods to construct, sign and broadcast
+    common transactions, such as posting, voting, sending funds, etc.
 
-        :param Hived hived: Hived node to connect to*
-        :param bool offline: Do **not** broadcast transactions! *(optional)*
-        :param bool debug: Enable Debugging *(optional)*
+    :param Hived hived: Hived node to connect to*
+    :param bool offline: Do **not** broadcast transactions! *(optional)*
+    :param bool debug: Enable Debugging *(optional)*
 
-        :param list,dict,string keys: Predefine the wif keys to shortcut the
-        wallet database
+    :param list,dict,string keys: Predefine the wif keys to shortcut the
+    wallet database
 
-        Three wallet operation modes are possible:
+    Three wallet operation modes are possible:
 
-        * **Wallet Database**: Here, the hivelibs load the keys from the
-          locally stored wallet SQLite database (see ``storage.py``).
-          To use this mode, simply call ``Hive()`` without the
-          ``keys`` parameter
-        * **Providing Keys**: Here, you can provide the keys for
-          your accounts manually. All you need to do is add the wif
-          keys for the accounts you want to use as a simple array
-          using the ``keys`` parameter to ``Hive()``.
-        * **Force keys**: This more is for advanced users and
-          requires that you know what you are doing. Here, the
-          ``keys`` parameter is a dictionary that overwrite the
-          ``active``, ``owner``, ``posting`` or ``memo`` keys for
-          any account. This mode is only used for *foreign*
-          signatures!
+    * **Wallet Database**: Here, the hivelibs load the keys from the
+      locally stored wallet SQLite database (see ``storage.py``).
+      To use this mode, simply call ``Hive()`` without the
+      ``keys`` parameter
+    * **Providing Keys**: Here, you can provide the keys for
+      your accounts manually. All you need to do is add the wif
+      keys for the accounts you want to use as a simple array
+      using the ``keys`` parameter to ``Hive()``.
+    * **Force keys**: This more is for advanced users and
+      requires that you know what you are doing. Here, the
+      ``keys`` parameter is a dictionary that overwrite the
+      ``active``, ``owner``, ``posting`` or ``memo`` keys for
+      any account. This mode is only used for *foreign*
+      signatures!
 
     """
 
@@ -91,30 +91,30 @@ class Commit(object):
         self.hived = hived_instance or shared_hived_instance()
         self.no_broadcast = no_broadcast
         self.unsigned = kwargs.get("unsigned", False)
-        self.expiration = int(kwargs.get("expiration", 60))
+        self.expiration = int(kwargs.get("expiration", 30))
 
         self.wallet = Wallet(self.hived, **kwargs)
 
     def finalizeOp(self, ops, account, permission):
-        """ This method obtains the required private keys if present in
-            the wallet, finalizes the transaction, signs it and
-            broadacasts it
+        """This method obtains the required private keys if present in
+        the wallet, finalizes the transaction, signs it and
+        broadacasts it
 
-            :param operation ops: The operation (or list of operaions) to
-                broadcast
+        :param operation ops: The operation (or list of operaions) to
+            broadcast
 
-            :param operation account: The account that authorizes the
-                operation
-            :param string permission: The required permission for
-                signing (active, owner, posting)
+        :param operation account: The account that authorizes the
+            operation
+        :param string permission: The required permission for
+            signing (active, owner, posting)
 
-            ... note::
+        ... note::
 
-                If ``ops`` is a list of operation, they all need to be
-                signable by the same key! Thus, you cannot combine ops
-                that require active permission with ops that require
-                posting permission. Neither can you use different
-                accounts for different operations!
+            If ``ops`` is a list of operation, they all need to be
+            signable by the same key! Thus, you cannot combine ops
+            that require active permission with ops that require
+            posting permission. Neither can you use different
+            accounts for different operations!
         """
         tx = TransactionBuilder(
             None,
@@ -134,13 +134,13 @@ class Commit(object):
         return tx.broadcast()
 
     def sign(self, unsigned_trx, wifs=[]):
-        """ Sign a provided transaction with the provided key(s)
+        """Sign a provided transaction with the provided key(s)
 
-            :param dict unsigned_trx: The transaction to be signed and returned
-            :param string wifs: One or many wif keys to use for signing
-                a transaction. If not present, the keys will be loaded
-                from the wallet as defined in "missing_signatures" key
-                of the transactions.
+        :param dict unsigned_trx: The transaction to be signed and returned
+        :param string wifs: One or many wif keys to use for signing
+            a transaction. If not present, the keys will be loaded
+            from the wallet as defined in "missing_signatures" key
+            of the transactions.
         """
         tx = TransactionBuilder(
             unsigned_trx,
@@ -154,9 +154,9 @@ class Commit(object):
         return tx.json()
 
     def broadcast(self, signed_trx):
-        """ Broadcast a transaction to the Hive network
+        """Broadcast a transaction to the Hive network
 
-            :param tx signed_trx: Signed transaction to broadcast
+        :param tx signed_trx: Signed transaction to broadcast
         """
         tx = TransactionBuilder(
             signed_trx,
@@ -181,7 +181,7 @@ class Commit(object):
         beneficiaries=None,
         self_vote=False,
     ):
-        """ Create a new post.
+        """Create a new post.
 
         If this post is intended as a reply/comment, `reply_identifier` needs
         to be set with the identifier of the parent post/comment (eg.
@@ -367,20 +367,20 @@ class Commit(object):
         return self.finalizeOp(ops, author, "posting")
 
     def vote(self, identifier, weight, account=None):
-        """ Vote for a post
+        """Vote for a post
 
-            :param str identifier: Identifier for the post to upvote Takes
-                                   the form ``author/permlink``
-            :param float weight: Voting weight. Range: -100.0 - +100.0. May
-                                 not be 0.0
-            :param str account: Voter to use for voting. (Optional)
+        :param str identifier: Identifier for the post to upvote Takes
+                               the form ``author/permlink``
+        :param float weight: Voting weight. Range: -100.0 - +100.0. May
+                             not be 0.0
+        :param str account: Voter to use for voting. (Optional)
 
-            If ``voter`` is not defines, the ``default_account`` will be taken
-            or a ValueError will be raised
+        If ``voter`` is not defines, the ``default_account`` will be taken
+        or a ValueError will be raised
 
-            .. code-block:: python
+        .. code-block:: python
 
-                hivepy set default_account <account>
+            hivepy set default_account <account>
         """
         if not account:
             account = configStorage.get("default_account")
@@ -417,10 +417,10 @@ class Commit(object):
         additional_posting_accounts=[],
         store_keys=True,
         store_owner_key=False,
-        delegation_fee_hive="0 HIVE",
+        delegation_fee_hive="0 SHTO",
         creator=None,
     ):
-        """ Create new account in Hive
+        """Create new account in Hive
 
             The brainkey/password can be used to recover all generated keys
             (see `hivebase.account` for more details.
@@ -587,12 +587,12 @@ class Commit(object):
         for k in additional_posting_accounts:
             posting_accounts_authority.append([k, 1])
 
-        props = self.steemd.get_chain_properties()
-        required_fee_steem = Amount(props["account_creation_fee"]).amount
+        props = self.hived.get_chain_properties()
+        required_fee_hive = Amount(props["account_creation_fee"])
 
         required_fee_vests = 0
-        delegation_fee_hive = Amount(delegation_fee_hive).amount
-        if delegation_fee_hive:
+        delegation_fee_hive = Amount(delegation_fee_hive)
+        if float(delegation_fee_hive):
             # creating accounts without delegation requires 30x
             # account_creation_fee creating account with delegation allows one
             # to use VESTS to pay the fee where the ratio must satisfy 1 HIVE
@@ -600,7 +600,7 @@ class Commit(object):
 
             delegated_hp_fee_mult = 5
 
-            if delegation_fee_hive < 1:
+            if float(delegation_fee_hive) < 1:
                 raise ValueError(
                     "When creating account with delegation, at least "
                     + "1 HIVE in fee must be paid."
@@ -608,14 +608,14 @@ class Commit(object):
 
             # calculate required remaining fee in vests
             remaining_fee = required_fee_hive - delegation_fee_hive
-            if remaining_fee > 0:
+            if float(remaining_fee) > 0:
                 required_hp = remaining_fee * delegated_hp_fee_mult
                 required_fee_vests = Converter().hp_to_vests(required_hp) + 1
 
         s = {
             "creator": creator,
-            "fee": "%s HIVE" % (delegation_fee_hive or required_fee_hive),
-            "delegation": "%s VESTS" % required_fee_vests,
+            "fee": "%.3s STEEM" % float(delegation_fee_hive or required_fee_hive),
+            # "delegation": "%s VESTS" % required_fee_vests,
             "json_metadata": json_meta or {},
             "memo_key": memo,
             "new_account_name": account_name,
@@ -636,25 +636,24 @@ class Commit(object):
             },
             "prefix": self.hived.chain_params["prefix"],
         }
-
         op = operations.AccountCreate(**s)
 
         return self.finalizeOp(op, creator, "active")
 
     def transfer(self, to, amount, asset, memo="", account=None):
-        """ Transfer HBD or HIVE to another account.
+        """Transfer HBD or HIVE to another account.
 
-            :param str to: Recipient
+        :param str to: Recipient
 
-            :param float amount: Amount to transfer
+        :param float amount: Amount to transfer
 
-            :param str asset: Asset to transfer (``HBD`` or ``HIVE``)
+        :param str asset: Asset to transfer (``HBD`` or ``HIVE``)
 
-            :param str memo: (optional) Memo, may begin with `#` for encrypted
-            messaging
+        :param str memo: (optional) Memo, may begin with `#` for encrypted
+        messaging
 
-            :param str account: (optional) the source account for the transfer
-            if not ``default_account``
+        :param str account: (optional) the source account for the transfer
+        if not ``default_account``
 
         """
         if not account:
@@ -706,15 +705,15 @@ class Commit(object):
         return self.finalizeOp(op, account, "active")
 
     def withdraw_vesting(self, amount, account=None):
-        """ Withdraw VESTS from the vesting account.
+        """Withdraw VESTS from the vesting account.
 
-            :param float amount: number of VESTS to withdraw over a period of
-            104 weeks
+        :param float amount: number of VESTS to withdraw over a period of
+        104 weeks
 
-            :param str account: (optional) the source account for the transfer
-            if not ``default_account``
+        :param str account: (optional) the source account for the transfer
+        if not ``default_account``
 
-    """
+        """
         if not account:
             account = configStorage.get("default_account")
         if not account:
@@ -732,7 +731,7 @@ class Commit(object):
         return self.finalizeOp(op, account, "active")
 
     def transfer_to_vesting(self, amount, to=None, account=None):
-        """ Vest HIVE
+        """Vest HIVE
 
         :param float amount: number of HIVE to vest
 
@@ -742,7 +741,7 @@ class Commit(object):
         :param str account: (optional) the source account for the transfer
         if not ``default_account``
 
-    """
+        """
         if not account:
             account = configStorage.get("default_account")
         if not account:
@@ -770,15 +769,15 @@ class Commit(object):
         return self.finalizeOp(op, account, "active")
 
     def convert(self, amount, account=None, request_id=None):
-        """ Convert HBD to HIVE (takes 3.5 days to settle)
+        """Convert HBD to HIVE (takes 3.5 days to settle)
 
-            :param float amount: number of HBD to convert
+        :param float amount: number of HBD to convert
 
-            :param str account: (optional) the source account for the transfer
-            if not ``default_account``
+        :param str account: (optional) the source account for the transfer
+        if not ``default_account``
 
-            :param str request_id: (optional) identifier for tracking the
-            conversion`
+        :param str request_id: (optional) identifier for tracking the
+        conversion`
 
         """
         if not account:
@@ -809,7 +808,7 @@ class Commit(object):
         reward_vests="0 VESTS",
         account=None,
     ):
-        """ Claim reward balances.
+        """Claim reward balances.
 
         By default, this will claim ``all`` outstanding balances. To bypass
         this behaviour, set desired claim amount by setting any of
@@ -872,7 +871,7 @@ class Commit(object):
         return self.finalizeOp(op, account, "posting")
 
     def delegate_vesting_shares(self, to_account, vesting_shares, account=None):
-        """ Delegate HP to another account.
+        """Delegate HP to another account.
 
         Args:
             to_account (string): Account we are delegating shares to
@@ -897,13 +896,13 @@ class Commit(object):
         return self.finalizeOp(op, account, "active")
 
     def witness_feed_publish(self, hive_usd_price, quote="1.000", account=None):
-        """ Publish a feed price as a witness.
+        """Publish a feed price as a witness.
 
-            :param float hive_usd_price: Price of HIVE in USD (implied price)
-            :param float quote: (optional) Quote Price. Should be 1.000, unless
-            we are adjusting the feed to support the peg.
-            :param str account: (optional) the source account for the transfer
-            if not ``default_account``
+        :param float hive_usd_price: Price of HIVE in USD (implied price)
+        :param float quote: (optional) Quote Price. Should be 1.000, unless
+        we are adjusting the feed to support the peg.
+        :param str account: (optional) the source account for the transfer
+        if not ``default_account``
         """
         if not account:
             account = configStorage.get("default_account")
@@ -922,20 +921,20 @@ class Commit(object):
         return self.finalizeOp(op, account, "active")
 
     def witness_update(self, signing_key, url, props, account=None):
-        """ Update witness
+        """Update witness
 
-            :param pubkey signing_key: Signing key
-            :param str url: URL
-            :param dict props: Properties
-            :param str account: (optional) witness account name
+        :param pubkey signing_key: Signing key
+        :param str url: URL
+        :param dict props: Properties
+        :param str account: (optional) witness account name
 
-             Properties:::
+         Properties:::
 
-                {
-                    "account_creation_fee": x,
-                    "maximum_block_size": x,
-                    "hbd_interest_rate": x,
-                }
+            {
+                "account_creation_fee": x,
+                "maximum_block_size": x,
+                "hbd_interest_rate": x,
+            }
 
         """
         if not account:
@@ -961,19 +960,19 @@ class Commit(object):
         return self.finalizeOp(op, account, "active")
 
     def witness_set_properties(self, signing_key, props, account=None):
-        """ Update witness
+        """Update witness
 
-            :param pubkey signing_key: Signing key
-            :param dict props: Properties
-            :param str account: (optional) witness account name
+        :param pubkey signing_key: Signing key
+        :param dict props: Properties
+        :param str account: (optional) witness account name
 
-             Properties:::
+         Properties:::
 
-                [
-                    ["account_creation_fee": x]
-                    ["maximum_block_size": x]
-                    ["sbd_interest_rate": x]
-                ]
+            [
+                ["account_creation_fee": x]
+                ["maximum_block_size": x]
+                ["sbd_interest_rate": x]
+            ]
 
         """
         if not account:
@@ -1020,8 +1019,7 @@ class Commit(object):
         return tb.broadcast()
 
     def decode_memo(self, enc_memo):
-        """ Try to decode an encrypted memo
-        """
+        """Try to decode an encrypted memo"""
         assert enc_memo[0] == "#", "decode memo requires memos to start with '#'"
         keys = memo.involved_keys(enc_memo)
         wif = None
@@ -1034,9 +1032,9 @@ class Commit(object):
         return memo.decode_memo(PrivateKey(wif), enc_memo)
 
     def interest(self, account):
-        """ Caluclate interest for an account
+        """Caluclate interest for an account
 
-            :param str account: Account name to get interest for
+        :param str account: Account name to get interest for
         """
         account = Account(account, hived_instance=self.hived)
         last_payment = fmt_time_string(account["hbd_last_interest_payment"])
@@ -1061,17 +1059,17 @@ class Commit(object):
     def set_withdraw_vesting_route(
         self, to, percentage=100, account=None, auto_vest=False
     ):
-        """ Set up a vesting withdraw route. When vesting shares are
-            withdrawn, they will be routed to these accounts based on the
-            specified weights.
+        """Set up a vesting withdraw route. When vesting shares are
+        withdrawn, they will be routed to these accounts based on the
+        specified weights.
 
-            :param str to: Recipient of the vesting withdrawal
-            :param float percentage: The percent of the withdraw to go
-                to the 'to' account.
-            :param str account: (optional) the vesting account
-            :param bool auto_vest: Set to true if the from account
-                should receive the VESTS as VESTS, or false if it should
-                receive them as HIVE. (defaults to ``False``)
+        :param str to: Recipient of the vesting withdrawal
+        :param float percentage: The percent of the withdraw to go
+            to the 'to' account.
+        :param str account: (optional) the vesting account
+        :param bool auto_vest: Set to true if the from account
+            should receive the VESTS as VESTS, or false if it should
+            receive them as HIVE. (defaults to ``False``)
         """
         if not account:
             account = configStorage.get("default_account")
@@ -1102,20 +1100,20 @@ class Commit(object):
     def allow(
         self, foreign, weight=None, permission="posting", account=None, threshold=None
     ):
-        """ Give additional access to an account by some other public
-            key or account.
+        """Give additional access to an account by some other public
+        key or account.
 
-            :param str foreign: The foreign account that will obtain access
-            :param int weight: (optional) The weight to use. If not
-                define, the threshold will be used. If the weight is
-                smaller than the threshold, additional signatures will
-                be required. (defaults to threshold)
-            :param str permission: (optional) The actual permission to
-                modify (defaults to ``posting``)
-            :param str account: (optional) the account to allow access
-                to (defaults to ``default_account``)
-            :param int threshold: The threshold that needs to be reached
-                by signatures to be able to interact
+        :param str foreign: The foreign account that will obtain access
+        :param int weight: (optional) The weight to use. If not
+            define, the threshold will be used. If the weight is
+            smaller than the threshold, additional signatures will
+            be required. (defaults to threshold)
+        :param str permission: (optional) The actual permission to
+            modify (defaults to ``posting``)
+        :param str account: (optional) the account to allow access
+            to (defaults to ``default_account``)
+        :param int threshold: The threshold that needs to be reached
+            by signatures to be able to interact
         """
         if not account:
             account = configStorage.get("default_account")
@@ -1159,16 +1157,16 @@ class Commit(object):
             return self.finalizeOp(op, account["name"], "active")
 
     def disallow(self, foreign, permission="posting", account=None, threshold=None):
-        """ Remove additional access to an account by some other public
-            key or account.
+        """Remove additional access to an account by some other public
+        key or account.
 
-            :param str foreign: The foreign account that will obtain access
-            :param str permission: (optional) The actual permission to
-                modify (defaults to ``posting``)
-            :param str account: (optional) the account to allow access
-                to (defaults to ``default_account``)
-            :param int threshold: The threshold that needs to be reached
-                by signatures to be able to interact
+        :param str foreign: The foreign account that will obtain access
+        :param str permission: (optional) The actual permission to
+            modify (defaults to ``posting``)
+        :param str account: (optional) the account to allow access
+            to (defaults to ``default_account``)
+        :param int threshold: The threshold that needs to be reached
+            by signatures to be able to interact
         """
         if not account:
             account = configStorage.get("default_account")
@@ -1239,14 +1237,14 @@ class Commit(object):
             return self.finalizeOp(op, account["name"], "active")
 
     def update_memo_key(self, key, account=None):
-        """ Update an account's memo public key
+        """Update an account's memo public key
 
-            This method does **not** add any private keys to your
-            wallet but merely changes the memo public key.
+        This method does **not** add any private keys to your
+        wallet but merely changes the memo public key.
 
-            :param str key: New memo public key
-            :param str account: (optional) the account to allow access
-                to (defaults to ``default_account``)
+        :param str key: New memo public key
+        :param str account: (optional) the account to allow access
+            to (defaults to ``default_account``)
         """
         if not account:
             account = configStorage.get("default_account")
@@ -1265,13 +1263,13 @@ class Commit(object):
         return self.finalizeOp(op, account["name"], "active")
 
     def approve_witness(self, witness, account=None, approve=True):
-        """ Vote **for** a witness. This method adds a witness to your
-            set of approved witnesses. To remove witnesses see
-            ``disapprove_witness``.
+        """Vote **for** a witness. This method adds a witness to your
+        set of approved witnesses. To remove witnesses see
+        ``disapprove_witness``.
 
-            :param str witness: witness to approve
-            :param str account: (optional) the account to allow access
-                to (defaults to ``default_account``)
+        :param str witness: witness to approve
+        :param str account: (optional) the account to allow access
+            to (defaults to ``default_account``)
         """
         if not account:
             account = configStorage.get("default_account")
@@ -1279,29 +1277,33 @@ class Commit(object):
             raise ValueError("You need to provide an account")
         account = Account(account, hived_instance=self.hived)
         op = operations.AccountWitnessVote(
-            **{"account": account["name"], "witness": witness, "approve": approve,}
+            **{
+                "account": account["name"],
+                "witness": witness,
+                "approve": approve,
+            }
         )
         return self.finalizeOp(op, account["name"], "active")
 
     def disapprove_witness(self, witness, account=None):
-        """ Remove vote for a witness. This method removes
-            a witness from your set of approved witnesses. To add
-            witnesses see ``approve_witness``.
+        """Remove vote for a witness. This method removes
+        a witness from your set of approved witnesses. To add
+        witnesses see ``approve_witness``.
 
-            :param str witness: witness to approve
-            :param str account: (optional) the account to allow access
-                to (defaults to ``default_account``)
+        :param str witness: witness to approve
+        :param str account: (optional) the account to allow access
+            to (defaults to ``default_account``)
         """
         return self.approve_witness(witness=witness, account=account, approve=False)
 
     def custom_json(self, id, json, required_auths=[], required_posting_auths=[]):
-        """ Create a custom json operation
+        """Create a custom json operation
 
-            :param str id: identifier for the custom json (max length 32 bytes)
-            :param json json: the json data to put into the custom_json
-                operation
-            :param list required_auths: (optional) required auths
-            :param list required_posting_auths: (optional) posting auths
+        :param str id: identifier for the custom json (max length 32 bytes)
+        :param json json: the json data to put into the custom_json
+            operation
+        :param list required_auths: (optional) required auths
+        :param list required_posting_auths: (optional) posting auths
         """
         account = None
         if len(required_auths):
@@ -1321,11 +1323,11 @@ class Commit(object):
         return self.finalizeOp(op, account, "posting")
 
     def reblog(self, identifier, account=None):
-        """ Reblog a post
+        """Reblog a post
 
-            :param str identifier: post identifier (<account>/<permlink>)
-            :param str account: (optional) the account to allow access
-                to (defaults to ``default_account``)
+        :param str identifier: post identifier (<account>/<permlink>)
+        :param str account: (optional) the account to allow access
+            to (defaults to ``default_account``)
         """
         if not account:
             account = configStorage.get("default_account")
@@ -1341,26 +1343,26 @@ class Commit(object):
         )
 
     def unfollow(self, unfollow, what=["blog"], account=None):
-        """ Unfollow another account's blog
+        """Unfollow another account's blog
 
-            :param str unfollow: Follow this account
-            :param list what: List of states to follow
-                (defaults to ``['blog']``)
-            :param str account: (optional) the account to allow access
-                to (defaults to ``default_account``)
+        :param str unfollow: Follow this account
+        :param list what: List of states to follow
+            (defaults to ``['blog']``)
+        :param str account: (optional) the account to allow access
+            to (defaults to ``default_account``)
         """
         # FIXME: removing 'blog' from the array requires to first read
         # the follow.what from the blockchain
         return self.follow(unfollow, what=[], account=account)
 
     def follow(self, follow, what=["blog"], account=None):
-        """ Follow another account's blog
+        """Follow another account's blog
 
-            :param str follow: Follow this account
-            :param list what: List of states to follow
-                (defaults to ``['blog']``)
-            :param str account: (optional) the account to allow access
-                to (defaults to ``default_account``)
+        :param str follow: Follow this account
+        :param list what: List of states to follow
+            (defaults to ``['blog']``)
+        :param str account: (optional) the account to allow access
+            to (defaults to ``default_account``)
         """
         if not account:
             account = configStorage.get("default_account")
@@ -1373,12 +1375,12 @@ class Commit(object):
         )
 
     def update_account_profile(self, profile, account=None):
-        """ Update an account's meta data (json_meta)
+        """Update an account's meta data (json_meta)
 
-            :param dict json: The meta data to use (i.e. use Profile() from
-                account.py)
-            :param str account: (optional) the account to allow access
-                to (defaults to ``default_account``)
+        :param dict json: The meta data to use (i.e. use Profile() from
+            account.py)
+        :param str account: (optional) the account to allow access
+            to (defaults to ``default_account``)
         """
         if not account:
             account = configStorage.get("default_account")
@@ -1395,23 +1397,23 @@ class Commit(object):
         return self.finalizeOp(op, account["name"], "active")
 
     def comment_options(self, identifier, options, account=None):
-        """ Set the comment options
+        """Set the comment options
 
-            :param str identifier: Post identifier
-            :param dict options: The options to define.
-            :param str account: (optional) the account to allow access
-                to (defaults to ``default_account``)
+        :param str identifier: Post identifier
+        :param dict options: The options to define.
+        :param str account: (optional) the account to allow access
+            to (defaults to ``default_account``)
 
-            For the options, you have these defaults:::
+        For the options, you have these defaults:::
 
-                    {
-                        "author": "",
-                        "permlink": "",
-                        "max_accepted_payout": "1000000.000 HBD",
-                        "percent_hive_dollars": 10000,
-                        "allow_votes": True,
-                        "allow_curation_rewards": True,
-                    }
+                {
+                    "author": "",
+                    "permlink": "",
+                    "max_accepted_payout": "1000000.000 HBD",
+                    "percent_hive_dollars": 10000,
+                    "allow_votes": True,
+                    "allow_curation_rewards": True,
+                }
 
         """
         if not account:
