@@ -1,11 +1,11 @@
-default_prefix = "BISON"
+default_prefix = "SHARE"
 
 known_chains = {
     "SHAREBERRY": {
         "chain_id": "a3ee3a34dd82dcd8e4f9ed14202c6d35734ea4c8d9c0e9daee48ec859d135b6c",
         "prefix": "SHARE",
-        "steem_symbol": "SHPO",
+        "steem_symbol": "SHTO",
         "sbd_symbol": "UNDEFINED",
-        "vests_symbol": "VESTS",
+        "vests_symbol": "SHPO",
     },
 }
